﻿Copyright (c) (2017) Fluke Corporation                      MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Tek TDS6000 Send Command, Wait for OPC SRQ
DATE:                  2018-09-10 07:46:45
AUTHOR:                Fluke Corporation
REVISION:              $Revision: 24954 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       117
=============================================================================
#
# Description:
#   This subprocedure is used to send a command to a Tektronix TDS 6000
#   series DSO and than wait for an operation complete (OPC) Service Request.
#
# Registers Used:
#
#   @Abort
#     = 0 OPC bit in Extended Status Register (ESR) is set
#     = 1 an error occurred
#
#   @HEAD_Text
#     Optional: If not blank will be used to update the head message.
#
#   @Cmd
#     Required: Command string to send to DUT.
#
#   @ErrorMsg
#     Contains error text when @Abort = 1
#
# Example Usage:
#
# 7.006  MATH         @HEAD_Text = "Waiting for DUT operation to complete..."
# 7.007  MATH         @Cmd = "INIT"
# 7.008  CALL         Sub Tek TDS6000 Send Command, Wait for OPC SRQ
# 7.009  JMPL         ABORT                       @Abort
#          .
#          .
#          .
# 9.001  LABEL        ABORT
# 9.002  DISP         [V @ErrorMsg]
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Save MEM
  1.001  MATH         BackupMEM = MEM; @Abort = 1

# Update HEAD message if specified.
  1.002  IF           ISVAR("@HEAD_Text")

  1.003  IF           NOT(EMPTY(@HEAD_Text))
  1.004  HEAD         [V @HEAD_Text]
  1.005  ENDIF

  1.006  ENDIF

  1.007  LABEL        SEND_COMMAND
# Setup conditions which will cause a Service Request (SRQ):
#     Request Service (RQS)                  64
#     Event Status Bit (ESB)                 32
#                                            --
#     Service Request Enable Register (SRE)  96
#
# Setup conditions which will set the ESB bit in the status byte:
#     Command Error (CME)                    32
#     Execution Error (EXE)                  16
#     Device Dependent Error (DDE)            8
#     Query Error (QYE)                       4
#     Operation Complete (OPC)                1
#                                            --
#     Event Status Enable Register (ESE)     61
#
# Wait up to 180s for the SRQ ([SRQ 180000]).
  1.008  IEEE         *CLS;*SRE 96;*ESE 61;[V @Cmd];*OPC[SRQ 180000]*SRE 0
# Test ESB in status byte.
  1.009  JMPL         QUERY_ESR                    BIT(5, MEM)
# No error or OPC.
  1.010  MATH         @ErrorMsg = "Unidentified DUT SRQ!  Status byte is "
  1.011  MATH         @ErrorMsg = @ErrorMsg & MEM
  1.012  JMPL         END

  1.013  LABEL        QUERY_ESR
# Get Extended Status Register (ESR) value
  1.014  IEEE         *ESR?[I]
# Check for OPC
  1.015  JMPL         OPERATION_COMPLETE           BIT(0, MEM)
# Check for any errors (CME, EXE, DDE, and QYE)
  1.016  JMPL         QUERY_EVENT_MESSAGE          BIT(5, MEM)
  1.017  JMPL         QUERY_EVENT_MESSAGE          BIT(4, MEM)
  1.018  JMPL         QUERY_EVENT_MESSAGE          BIT(3, MEM)
  1.019  JMPL         QUERY_EVENT_MESSAGE          BIT(2, MEM)

  1.020  LABEL        OPERATION_COMPLETE
  1.021  MATH         @Abort = 0

  1.022  LABEL        QUERY_EVENT_MESSAGE
  1.023  IEEE         EVMSG?[I$]
  1.024  MATH         @ErrorMsg = MEM2
# Get the event message number.
  1.025  MATH         MEM = MEM2
# Check for end of queue.
  1.026  JMPL         END                          MEM == 0
# 402,"Operation complete"
  1.027  JMPL         QUERY_EVENT_MESSAGE          MEM == 402

# 420,"Query UNTERMINATED" (ignore if OPC is also set)
  1.028  MATH         MEM1 = (MEM == 420) + @Abort
  1.029  JMPL         QUERY_EVENT_MESSAGE          MEM1 == 2
  1.030  OPBR         [V @ErrorMsg]
  1.030  OPBR
  1.030  OPBR         Do you wish to send the command again?
  1.031  JMPL         SEND_COMMAND                 MEM1 > 0
  1.032  JMPL         QUERY_EVENT_MESSAGE

  1.033  LABEL        END
  1.034  MATH         MEM = BackupMEM
  1.035  END
